@@ -1,14 +1,20 @@
+# Copyright (c) 2016-2022 Association of Universities for Research in Astronomy, Inc. (AURA)
+# For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
+
 from dataclasses import dataclass
 from typing import Optional
 
 
 @dataclass(frozen=True)
 class Resource:
-    """
-    This is a general observatory resource.
+    """This is a general observatory resource.
     It can consist of a guider, an instrument, or a part of an instrument,
     or even a personnel and is used to determine what observations can be
     performed at a given time based on the resource availability.
+
+    Attributes:
+        id (str): Resource id or name.
+        description (str): Short description.
     """
     id: str
     description: Optional[str] = None
@@ -21,4 +27,4 @@ class Resource:
         return isinstance(other, Resource) and self.id == other.id
 
     def __repr__(self):
-        return f'Resource(id=\'{self.id}\')'
+        return f"Resource(id='{self.id}')"
